Skip to main content

git-ctm = git commit Time Machine

Sometimes you need to create a commit with particular timestamp. git-ctm provides a command-line tool ctm for easy committing with desired timestamp:

$ ctm -d 'Thu Feb 8 03:14:15 2018 +0200' -m 'my commit message'

# is the same as
$ GIT_AUTHOR_DATE='Thu Feb 8 03:14:15 2018 +0200'    \
  GIT_COMMITTER_DATE='Thu Feb 8 03:14:15 2018 +0200' \
  git commit -m 'my commit message'

All commits in this project are done with ctm itself.

Installation

From PyPI using pip package manager:

pip install --upgrade git-ctm

Or install the latest sources from GitHub:

pip install https://github.com/pavdmyt/git-ctm/archive/master.zip

Or just put ctm PEX (Python EXecutable) file somewhere in the $PATH:

$ git clone https://github.com/pavdmyt/git-ctm.git
$ cd git-ctm
$ sudo cp ctm /usr/local/bin/

Now ctm command-line tool should be available to use, try:

ctm --version

Usage

$ ctm --help
Usage:  ctm -d <date> -m <msg>
        ctm -p

  -d <date>      Commit date and time
  -m <msg>       Commit message
  -p             Print date template

  --help         Print usage
  --version      Print version

Development

Clone the repository:

git clone https://github.com/pavdmyt/git-ctm.git

Install dependencies:

make install-dev

Lint code:

make lint

Contributing

  1. Fork it!

  2. Create your feature branch: git checkout -b my-new-feature

  3. Commit your changes: git commit -m 'Add some feature'

  4. Push to the branch: git push origin my-new-feature

  5. Submit a pull request

  6. Make sure tests are passing

License

MIT - Pavlo Dmytrenko

Metadata

Release files for git-ctm 0.2.0

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for git-ctm 0.2.0
File Size Uploaded
git-ctm-0.2.0.tar.gz 4.4 kB Details

Built distribution (wheel)

Table of built distributions (wheels) for git-ctm 0.2.0
File Interpreter ABI Platform
git_ctm-0.2.0-py2.py3-none-any.whl Python 3, Python 2 none any Details

Total release size: 9.8 kB

Release files / git-ctm-0.2.0.tar.gz

Download URL git-ctm-0.2.0.tar.gz
Size 4.4 kB
Tags Source
SHA-256 checksum
How to use checksums
0651d02ef48d6be087c1b1e8fb8a9df81228a8db7976c4c1fe170e02b603c7bc
BLAKE2b-256 checksum
How to use checksums
69515c59dd380c748c5532c450218395220fa59f47cfbc3e5e1402d4cc694623
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No

Release files / git_ctm-0.2.0-py2.py3-none-any.whl

Download URL git_ctm-0.2.0-py2.py3-none-any.whl
Size 5.4 kB
Tags Python 2 Python 3
SHA-256 checksum
How to use checksums
0aeaa50394baa982db1aebb360bcd6dd12071fe9272d65b7801c8d14bf09fb25
BLAKE2b-256 checksum
How to use checksums
5b10389ef8ac49453ad2a8895e57b5828d34389c9657776b56c5efec0533774d
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No

Release history Release notifications | RSS feed

This release

0.2.0 This release

2 release files

0.1.0

2 release files

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page